------------------------------------------------------------------------------
--
-- Filename:              compare.vhd
-- Inhalt:                Modell eines Komparators fuer Bit-Vektoren
--                        beliebiger Breite:
--
--                        Ausgang (result) = '1', falls a > b,
--                                         = '0', falls a <= b
--
--                        realisiert mit verschiedenen Architekturen:
--
--                        - ARCHITECTURE  "behavioral_1" (sequentiell)
--                        - ARCHITECTURE  "behavioral_2" (nebenlaeufig)
--
------------------------------------------------------------------------------
--
-- Autor:                Bernhard Wunder  
-- Letzte Aenderung:     03.03.1994
--
------------------------------------------------------------------------------

ENTITY compare IS 

   GENERIC (n : positive := 4);
   PORT (a, b : IN bit_vector ( n-1 DOWNTO 0 ); result: OUT bit);  

END compare;

------------------------------------------------------------------------------
------------------------------------------------------------------------------

ARCHITECTURE behavioral_1 OF compare IS

BEGIN

    PROCESS (a, b)

    BEGIN
	IF a > b THEN
           result <= '1';
        ELSE
           result <= '0';
        END IF;
    END PROCESS;

END behavioral_1;

--------------------------------------------------------------------------------

ARCHITECTURE behavioral_2 OF compare IS

BEGIN

   result <= '1' WHEN a > b ELSE
             '0';

END behavioral_2;

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

CONFIGURATION compare_config1 OF compare IS

    FOR behavioral_1                 
    END FOR;     

END compare_config1;

--------------------------------------------------------------------------------
                  
CONFIGURATION compare_config2 OF compare IS

    FOR behavioral_2                 
    END FOR;                     

END compare_config2;

