------------------------------------------------------------------------------
--
-- Filename:                aoi93.vhd
-- Inhalt:                  Modell eines AND-OR-INVERT-Komplexgatters
--                          verwendet Typ "bit"
--
-- !!! ACHTUNG !!!          verwendet Elemente der Syntax VHDL`93
--
------------------------------------------------------------------------------
--
-- Autor:                   Bernhard Wunder  
-- Letzte Aenderung:        18.01.94
--
------------------------------------------------------------------------------

ENTITY aoi IS
    
    PORT (a1, a2, a3, b1, b2 : IN bit;
          y: OUT bit);                 -- implizite Signale

END aoi;

------------------------------------------------------------------------------
--
-- structural_2: Strukturale Architektur mit konstantem Ausdruck in
--               der PORT MAP der Komponenteninstantiierung und einem 
--               offenen Pin aufgrund Verwendung von
--               Sockeln/Modellen mit mehr Pins als noetig
--
------------------------------------------------------------------------------

ARCHITECTURE structural_2 OF aoi IS   -- !! VHDL93-Syntax !!

  SIGNAL a_out, b_out : bit ;         -- interne Signale

  COMPONENT nor3                      -- invertierendes OR3
    PORT (a,b,c : IN bit := '0' ; y : OUT bit) ;
  END COMPONENT nor3 ; -- Wiederholung des Komponentennamens
  
  COMPONENT and3                      -- nur 3_fach AND
    PORT (a,b,c : IN bit := '0' ; y : OUT bit) ;
  END COMPONENT and3 ; -- Wiederholung des Komponentennamens

BEGIN

  and_a : and3 PORT MAP (a1,a2,a3,a_out);
  and_b : and3 PORT MAP (a=>b2, b=>b1, c=>'1', y=>b_out);
               -- AND2-Funktion mit AND3-Sockel:
               -- Port "c" wird konstant auf '1' gelegt
  nor_c : nor3 PORT MAP (OPEN, a_out, y=>y, c=>b_out);
               -- NOR2-Funktion mit NOR3-Sockel:
               -- Port "a" bleibt unangeschlossen

END structural_2 ;

------------------------------------------------------------------------------

CONFIGURATION aoi_config_2 OF aoi IS

  FOR structural_2
        FOR ALL   : and3 USE ENTITY work.and3 (behavioral) ;
        END FOR ;
        FOR nor_c : nor3 USE ENTITY work.nor4 (behavioral) 
          PORT MAP (a=>OPEN,b=>a,c=>b,d=>c,y=>y) ;
          -- NOR3-Sockel mit NOR4-Entity bestueckt: 
          -- OPEN als ACTUAL fuer ueberflussigen PORT
        END FOR ;
  END FOR;

END aoi_config_2 ;

------------------------------------------------------------------------------
--
-- structural_3: Strukturale Architektur mit direkter Instantiierung, d.h.
--               ohne explizite Konfiguration!
--
------------------------------------------------------------------------------

ARCHITECTURE structural_3 OF aoi IS   -- !! VHDL93-Syntax !!

  SIGNAL a_out, b_out : bit ;         -- interne Signale

BEGIN

  and_a : ENTITY work.and3 (behavioral) 
          PORT MAP (a1, a2, a3, a_out);
  and_b : ENTITY work.and2 (behavioral)
          PORT MAP (b1, b2, b_out);
  nor_c : CONFIGURATION work.nor2_config
          PORT MAP (a_out, b_out, y);

END structural_3 ;
      
------------------------------------------------------------------------------

-- CONFIGURATION aoi_config_3 OF aoi IS      -- Nicht erforderlich !!!

------------------------------------------------------------------------------
--
-- structural_7: Strukturale Architektur mit getrennter PORT MAP (Architecture)
--               und GENERIC MAP (Configuration)
--
------------------------------------------------------------------------------

ARCHITECTURE structural_7 OF aoi IS   -- !! VHDL93-Syntax !!

  SIGNAL a_out, b_out, or_out: bit ;  -- interne Signale

  COMPONENT inv
    GENERIC (tpd_lh, tpd_hl : time := 0.8 ns) ;
    PORT (a : IN bit; y : OUT bit) ;
  END COMPONENT ;

  COMPONENT or2
    GENERIC (tpd_lh : time := 1.5 ns; tpd_hl : time := 1 ns) ;
    PORT (a,b : IN bit; y : OUT bit) ;
  END COMPONENT ;

  COMPONENT and2
    GENERIC (tpd_lh : time := 1 ns; tpd_hl : time := 1.5 ns) ;
    PORT (a,b : IN bit; y : OUT bit) ;
  END COMPONENT ;

  COMPONENT and3
    GENERIC (tpd_lh : time := 1 ns; tpd_hl : time := 1.8 ns) ;
    PORT (a,b,c : IN bit; y : OUT bit) ;
  END COMPONENT ;

  FOR ALL : inv  USE ENTITY work.not1 (behavioral)
                 GENERIC MAP (0.75 ns, 0.7 ns) ;
  FOR ALL : or2  USE ENTITY work.or2 (behavioral)
                 GENERIC MAP (1.6 ns, 1.5 ns) ;
  FOR ALL : and2 USE CONFIGURATION work.and2_config ;
  FOR ALL : and3 USE CONFIGURATION work.and3_config ;

BEGIN

  and_a : and3 PORT MAP (a1,a2,a3,a_out) ;       
  and_b : and2 PORT MAP (b=>b1,y=>b_out,a=>b2) ;
  or_c  : or2  PORT MAP (a_out,y=>or_out,b=>b_out) ;
  inv_d : inv  PORT MAP (or_out,y) ;

END structural_7 ;
      
------------------------------------------------------------------------------

CONFIGURATION aoi_config_7 OF aoi IS

    FOR structural_7
        FOR inv_d : inv  GENERIC MAP (0.9 ns, 0.8 ns) ; END FOR ;
        FOR or_c  : or2  GENERIC MAP (1.8 ns, 1.7 ns) ; END FOR ;
        FOR and_b : and2 GENERIC MAP (1.3 ns, 1.9 ns) ; END FOR ;
        FOR and_a : and3 GENERIC MAP (1.4 ns, 2.0 ns) ; END FOR ;
    END FOR ;

END aoi_config_7 ;
