------------------------------------------------------------------------------
--
-- Filename:                count5.vhd
-- Inhalt:                  Beispiel zur Verhaltensmodellierung
--                          Synchroner, zyklischer Zaehler von 0 bis 4
--                          Zaehlen nur bei enable = '1'
--                          Asynchrones, low-aktives Ruecksetzsignal reset
--                          Ein- und Ausgangssignale vom Typ bit
--
------------------------------------------------------------------------------
--
-- Autor:                   Gunther Lehmann  
-- Letzte Aenderung:        01.03.1994
--
------------------------------------------------------------------------------

ENTITY count5 IS

  PORT (clk, enable, reset : IN  bit;
        q                  : OUT bit_vector (2 DOWNTO 0));

END count5;

------------------------------------------------------------------------------

ARCHITECTURE behavioral OF count5 IS

  SIGNAL state : integer RANGE 0 TO 4 := 0; -- Zaehlerstand
    
BEGIN

  count : PROCESS (clk, reset)

  BEGIN

    IF reset = '0' THEN                     -- asynchrones Reset
      state <= 0;
    ELSIF (enable = '1' AND clk'EVENT AND clk = '1') THEN
      IF state < 4 THEN
        state <= state + 1;
      ELSE
        state <= 0;
      END IF;
    END IF;

  END PROCESS count;

  q <= ('0','0','0') WHEN state = 0 ELSE    -- Ausgangswerte
       ('0','0','1') WHEN state = 1 ELSE
       ('0','1','0') WHEN state = 2 ELSE
       ('0','1','1') WHEN state = 3 ELSE
       ('1','0','0');

END behavioral;

------------------------------------------------------------------------------

CONFIGURATION count5_config OF count5 IS

    FOR behavioral
    END FOR;

END count5_config;


