------------------------------------------------------------------------------
--
-- Filename:                file_io.vhd
-- Inhalt:                  Beispiele zum Datentransfer von und zu Files.
--                          Das Modell erzeugt Stimuli anhand des Files stimres
--                          und gibt diese an das Modell model_under_test
--                          Abweichungen von den erwarteten Antworten werden
--                          in die Datei errors geschrieben.
--                          Modell verwendet and3.vhd (vorher uebersetzen!)
--
------------------------------------------------------------------------------
--
-- Autor:                   Bernhard Wunder 
-- Letzte Aenderung:        10.02.94
--
------------------------------------------------------------------------------

USE  std.textio.ALL;

ENTITY tb_3pin IS
END tb_3pin;


------------------------------------------------------------------------------

ARCHITECTURE arch_1 OF tb_3pin IS

  SIGNAL a,b,c,r,y: bit;
 
  COMPONENT mut_socket
    PORT (a,b,c: IN  bit;
          y    : OUT bit);
  END COMPONENT;

  FILE stimres : text IS IN  "stimres";
  FILE errors  : text IS OUT "errors";

BEGIN

  ------------------------------------------------------- zu testendes Modell
  model_under_test: mut_socket PORT MAP (a,b,c,y);


  ---------------------------------------------------------- Stimulierzeugung
  read_stimuli: PROCESS
    VARIABLE lin           : line;
    VARIABLE boo           : boolean;
    VARIABLE t             : time;
    VARIABLE str_var,space : character;
    VARIABLE data          : bit;
  BEGIN 
    WHILE (endfile(stimres) = false) LOOP
      READLINE (stimres, lin);
			
      READ (lin,str_var,boo);
      ASSERT boo REPORT "Error reading file!" SEVERITY failure;

      IF ((str_var = 'a') OR (str_var = 'b') 
       OR (str_var = 'c') OR (str_var = 'r')) THEN
         READ (lin,space); 
         READ (lin,data);
         READ (lin,space);
         READ (lin,t);

         CASE str_var IS
           WHEN 'a' => a <= TRANSPORT data AFTER t;
           WHEN 'b' => b <= TRANSPORT data AFTER t;
           WHEN 'c' => c <= TRANSPORT data AFTER t;
           WHEN 'r' => r <= TRANSPORT data AFTER t;
           WHEN OTHERS => NULL;
         END CASE;
      END IF;
    END LOOP;
    WAIT;
  END PROCESS;


  ------------------------------------------------------------ Ueberpruefung
  write_errors : PROCESS
    VARIABLE lin : line;
  BEGIN
    WAIT ON r'TRANSACTION;
    IF (y /= r) THEN
      WRITE (lin, string'("y isn't "));
      WRITE (lin, r);
      WRITE (lin, string'(" at time "));
      WRITE (lin, NOW);
      WRITELINE (errors,lin);
    END IF;
  END PROCESS;

END arch_1;


-------------------------------------------------------------------------------

CONFIGURATION tb_config OF tb_3pin IS
    FOR arch_1
        FOR model_under_test: mut_socket USE ENTITY work.and3 (behavioral) ;
        END FOR;
    END FOR;
END tb_config;


