------------------------------------------------------------------------------
--
-- Filename:                sim_cyc.vhd
-- Inhalt:                  Verdeutlichung des Simulationszyklus am Beispiel
--                          von Variablen- und Signalzuweisungen
--                          Weitere Erlaeuterungen im Buch
--
------------------------------------------------------------------------------
--
-- Autor:                   Bernhard Wunder 
-- Letzte Aenderung:        10.02.94
--
------------------------------------------------------------------------------

ENTITY example IS
 
END example ;

------------------------------------------------------------------------------
-- number_one: Signalzuweisung auf b bedingt, dass Variable c erst beim 
--             naechsten Prozessdurchlauf aktualisiert wird!
------------------------------------------------------------------------------

ARCHITECTURE number_one OF example IS

  SIGNAL a,b : integer := 0 ;

BEGIN

  a <= 1 AFTER 1 ns, 2 AFTER 2 ns, 3 AFTER 3 ns;
  PROCESS (a)
    VARIABLE c : integer := 0;
  BEGIN
    b <= a + 2;
    c := 2 * b;
  END PROCESS;

END number_one ;

------------------------------------------------------------------------------
-- number_two: WAIT-Anweisung erzwingt Signalzuweisung (und neuen 
--             Delta-Zyklus) vor Weiterbearbeitung des Prozesses
------------------------------------------------------------------------------

ARCHITECTURE number_two OF example IS

  SIGNAL a,b : integer := 0 ;

BEGIN

  a <= 1 AFTER 1 ns, 2 AFTER 2 ns, 3 AFTER 3 ns;
  PROCESS
    VARIABLE c : integer := 0;
  BEGIN
    b <= a + 2;
    WAIT ON b;
    c := 2 * b;
    WAIT ON a;
  END PROCESS;

END number_two ;

------------------------------------------------------------------------------
-- number_three: b in der sensitivity-list fuehrt auf neuen Prozessdurchlauf
--               bei einer Aenderung von b (neuer Delta-Zyklus) 
------------------------------------------------------------------------------

ARCHITECTURE number_three OF example IS

  SIGNAL a,b : integer := 0 ;

BEGIN

  a <= 1 AFTER 1 ns, 2 AFTER 2 ns, 3 AFTER 3 ns;
  PROCESS (a, b)
    VARIABLE c : integer := 0;
  BEGIN
    b <= a + 2;
    c := 2 * b;
  END PROCESS;

END number_three ;

------------------------------------------------------------------------------
-- number_four: Zuweisung auf b als Variable wird sofort durchgefuehrt
------------------------------------------------------------------------------
 
ARCHITECTURE number_four OF example IS

  SIGNAL a : integer := 0 ;

BEGIN

  a <= 1 AFTER 1 ns, 2 AFTER 2 ns, 3 AFTER 3 ns;
  PROCESS (a)
    VARIABLE b,c : integer := 0;
  BEGIN
    b := a + 2;
    c := 2 * b;
  END PROCESS;

END number_four ;

------------------------------------------------------------------------------

CONFIGURATION example_config OF example IS

  FOR number_one 
  END FOR ;

END example_config ;
