------------------------------------------------------------------------------
--
-- Filename:                dec_stim.vhd
-- Inhalt:                  Stimulibeschreibung fuer einen 8-bit Decoder
--                          Zyklisches Ausgeben der Werte 0 bis 255 als
--                          Bitvektor ueber den Ausgang stim
--
------------------------------------------------------------------------------
--
-- Autor:                   Bernhard Wunder  
-- Letzte Aenderung:        18.02.1994
--
------------------------------------------------------------------------------

ENTITY dec_stim IS

  PORT (stim : OUT bit_vector (7 DOWNTO 0));

END dec_stim;

------------------------------------------------------------------------------

ARCHITECTURE behavioral OF dec_stim IS

    FUNCTION integer_to_bit (a : integer) RETURN bit_vector IS
        VARIABLE count : integer := -1 ;
        VARIABLE result : bit_vector(7 DOWNTO 0) ;
        VARIABLE int_val : integer := a;
    BEGIN
        ASSERT int_val <= 255 REPORT "Integer can't be represented by 8 bit" 
                              SEVERITY failure ;
        WHILE int_val > 0 LOOP
            count := count + 1;
            IF int_val MOD 2 = 1 THEN
                int_val := int_val - 1;
                result(count) := '1';
            END IF;
            int_val := int_val / 2;
        END LOOP;
        RETURN result;
    END ;

BEGIN

  stimuli_generation: PROCESS
    VARIABLE a : integer := 0;
  BEGIN
    WAIT FOR 10 ns;
    stim <= integer_to_bit(a);
    a := a + 1;
    IF a > 255 THEN a := a -256; END IF;
  END PROCESS;

END behavioral;

