------------------------------------------------------------------------------
--
-- Filename:                nand2_tb.vhd
-- Inhalt:                  Beispiele fuer Testumgebungen
--
------------------------------------------------------------------------------
--
-- Autor:                   Bernhard Wunder 
-- Letzte Aenderung:        18.02.94
--
------------------------------------------------------------------------------

ENTITY nand2_tb IS

END nand2_tb;

------------------------------------------------------------------------------

ARCHITECTURE strategy_1 OF nand2_tb IS

    COMPONENT nand2_socket
        PORT (in1, in2 : IN bit ; out1 : OUT bit);
    END COMPONENT;

    SIGNAL a,b,c : bit;

    SUBTYPE t2 IS bit_vector(1 TO 2);

BEGIN

  mut : nand2_socket PORT MAP (a,b,c); -- Model under Test

  stimuli_generation : PROCESS
  BEGIN

    -----------------------------------------------------------
    -- Stimulibeschreibung zum Zeitnullpunkt in einer Anweisung
    -----------------------------------------------------------

    (a,b) <= t2'("01") AFTER  10 ns,
             t2'("10") AFTER  20 ns,
             t2'("11") AFTER  30 ns,
             t2'("00") AFTER  40 ns;
    WAIT;
  END PROCESS;

  response_control: PROCESS
  BEGIN
 
    ------------------------------------------------
    -- erwartete Antworten: pruefe 2 ns nach Stimuli
    ------------------------------------------------

    WAIT FOR  12 ns;                    -- absolute Zeit: 12 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 22 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 32 ns 
    ASSERT c='0' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 42 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT;                                       -- Ende der Simulation
  END PROCESS;

END strategy_1;

------------------------------------------------------------------------------

ARCHITECTURE strategy_1a OF nand2_tb IS

    COMPONENT nand2_socket
        PORT (in1, in2 : IN bit ; out1 : OUT bit);
    END COMPONENT;

    SIGNAL a,b,c : bit;

    SUBTYPE t2 IS bit_vector(1 TO 2);

BEGIN

  mut : nand2_socket PORT MAP (a,b,c); -- Model under Test

  single_step_stimuli_generation : PROCESS
  BEGIN

    -----------------------------------------------------------------
    -- Stimulibeschreibung zum Zeitnullpunkt in einzelnen Anweisungen
    -----------------------------------------------------------------

    (a,b) <= TRANSPORT t2'("01") AFTER  10 ns;
    (a,b) <= TRANSPORT t2'("10") AFTER  20 ns;
    (a,b) <= TRANSPORT t2'("11") AFTER  30 ns;
    (a,b) <= TRANSPORT t2'("00") AFTER  40 ns;
    WAIT;
  END PROCESS;

  response_control: PROCESS
  BEGIN
 
    ------------------------------------------------
    -- erwartete Antworten: pruefe 2 ns nach Stimuli
    ------------------------------------------------

    WAIT FOR  12 ns;                    -- absolute Zeit: 12 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 22 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 32 ns 
    ASSERT c='0' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 42 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT;                                       -- Ende der Simulation
  END PROCESS;

END strategy_1a;

------------------------------------------------------------------------------

ARCHITECTURE strategy_1b OF nand2_tb IS

    COMPONENT nand2_socket
        PORT (in1, in2 : IN bit ; out1 : OUT bit);
    END COMPONENT;

    SIGNAL a,b,c : bit;

    SUBTYPE t2 IS bit_vector(1 TO 2);

BEGIN

  mut : nand2_socket PORT MAP (a,b,c); -- Model under Test

  single_step_stimuli_generation : PROCESS
  BEGIN

    ---------------------------------------------------
    -- Stimulibeschreibung zum entsprechenden Zeitpunkt
    ---------------------------------------------------

    WAIT FOR 10 ns;
    (a,b) <= t2'("01");
    WAIT FOR 10 ns;
    (a,b) <= t2'("10");
    WAIT FOR 10 ns;
    (a,b) <= t2'("11");
    WAIT FOR 10 ns;
    (a,b) <= t2'("00");
    WAIT;
  END PROCESS;

  response_control: PROCESS
  BEGIN
 
    ------------------------------------------------
    -- erwartete Antworten: pruefe 2 ns nach Stimuli
    ------------------------------------------------

    WAIT FOR  12 ns;                    -- absolute Zeit: 12 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 22 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 32 ns 
    ASSERT c='0' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR  10 ns;                    -- absolute Zeit: 42 ns 
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT;                                       -- Ende der Simulation
  END PROCESS;

END strategy_1b;

------------------------------------------------------------------------------

ARCHITECTURE strategy_1c OF nand2_tb IS

    COMPONENT nand2_socket
        PORT (in1, in2 : IN bit ; out1 : OUT bit);
    END COMPONENT;

    SIGNAL a,b,c : bit;

    SUBTYPE t2 IS bit_vector(1 TO 2);

BEGIN

  mut : nand2_socket PORT MAP (a,b,c); -- Model under Test

  stimuli_generation_and_response_control : PROCESS
  BEGIN

    -------------------------------------------------------
    -- Stimulibeschreibung zum entsprechenden Zeitpunkt
    -- und anschliessende Antwortkontrolle in einem Prozess
    -------------------------------------------------------

    WAIT FOR 10 ns;
    (a,b) <= t2'("01");
    WAIT FOR 2 ns;
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR 8 ns;
    (a,b) <= t2'("10");
    WAIT FOR 2 ns;
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR 8 ns;
    (a,b) <= t2'("11");
    WAIT FOR 2 ns;
    ASSERT c='0' REPORT "wrong_result"   SEVERITY note;
    WAIT FOR 8 ns;
    (a,b) <= t2'("00");
    WAIT FOR 2 ns;
    ASSERT c='1' REPORT "wrong_result"   SEVERITY note;
    WAIT;                                      -- Ende der Simulation
  END PROCESS;

END strategy_1c;

------------------------------------------------------------------------------

CONFIGURATION nand2_tb_config OF nand2_tb IS

    FOR strategy_1
        FOR mut : nand2_socket USE ENTITY work.nand2 (number_one)
            PORT MAP (in1, in2, out1);
        END FOR;
    END FOR;

END nand2_tb_config;
