------------------------------------------------------------------------------
--
-- Filename:                adder_tb.vhd
-- Aufgabe:                 2.1.4
-- Inhalt:                  Beispiel einer Testumgebung
--
------------------------------------------------------------------------------
--
-- Autor:                   Bernhard Wunder 
-- Letzte Aenderung:        07.02.94
--
------------------------------------------------------------------------------

ENTITY fulladder_tb IS

END fulladder_tb;

------------------------------------------------------------------------------

ARCHITECTURE arch_1 OF fulladder_tb IS

    SUBTYPE stim IS bit_vector(1 TO 3);

    SIGNAL sum_a,sum_b,sum_c,sum,carry : bit;

    COMPONENT adder_socket
        PORT (x1,x2,x3 : IN  bit; 
              x4,x5    : OUT bit);
    END COMPONENT;

BEGIN

  model_under_test: adder_socket PORT MAP (sum_a,sum_b,sum_c,
                                             sum, carry); -- Instanz MUT

  PROCESS

  BEGIN

   ----------------------------------------
   -- Stimulibeschreibung zum Zeitnullpunkt
   ----------------------------------------

    (sum_a, sum_b, sum_c) <= stim'('0', '0', '0') AFTER  0 ns,
                             stim'('0', '0', '1') AFTER  5 ns,
                             stim'('0', '1', '0') AFTER  10 ns,
                             stim'('0', '1', '1') AFTER  15 ns,
                             stim'('1', '0', '0') AFTER  20 ns,
                             stim'('1', '0', '1') AFTER  25 ns,
                             stim'('1', '1', '0') AFTER  30 ns,
                             stim'('1', '1', '1') AFTER  35 ns;

    ------------------------------------------------
    -- erwartete Antworten: pruefe 1 ns nach Stimuli
    ------------------------------------------------

    WAIT FOR  1 ns; -- absolute Zeit: 1 ns 
    ASSERT (sum   = '0') REPORT "sum isn't 0"   SEVERITY failure;
    ASSERT (carry = '0') REPORT "carry isn't 0" SEVERITY failure;

    WAIT FOR  5 ns; -- absolute Zeit: 6 ns
    ASSERT (sum   = '1') REPORT "sum isn't 1"   SEVERITY failure;
    ASSERT (carry = '0') REPORT "carry isn't 0" SEVERITY failure;

    WAIT FOR  5 ns; -- absolute Zeit: 11 ns 
    ASSERT (sum   = '1') REPORT "sum isn't 1"   SEVERITY failure;
    ASSERT (carry = '0') REPORT "carry isn't 0" SEVERITY failure;

    WAIT FOR  5 ns; -- absolute Zeit: 16 ns
    ASSERT (sum   = '0') REPORT "sum isn't 0"   SEVERITY failure;
    ASSERT (carry = '1') REPORT "carry isn't 1" SEVERITY failure;

    WAIT FOR  5 ns; -- absolute Zeit: 21 ns
    ASSERT (sum   = '1') REPORT "sum isn't 1"   SEVERITY failure;
    ASSERT (carry = '0') REPORT "carry isn't 0" SEVERITY failure;

    WAIT FOR  5 ns; -- absolute Zeit: 26 ns 
    ASSERT (sum   = '0') REPORT "sum isn't 0"   SEVERITY failure;
    ASSERT (carry = '1') REPORT "carry isn't 1" SEVERITY failure;

    WAIT FOR  5 ns; -- absolute Zeit: 31 ns
    ASSERT (sum   = '0') REPORT "sum isn't 0"   SEVERITY failure;
    ASSERT (carry = '1') REPORT "carry isn't 1" SEVERITY failure;

    WAIT FOR  5 ns; -- absolute Zeit: 36 ns
    ASSERT (sum   = '1') REPORT "sum isn't 1"   SEVERITY failure;
    ASSERT (carry = '1') REPORT "carry isn't 1" SEVERITY failure;

    WAIT;                                       -- Ende der Simulation

    END PROCESS;

END arch_1;

------------------------------------------------------------------------------

CONFIGURATION fulladder_tb_config OF fulladder_tb IS

    FOR arch_1
        FOR model_under_test: adder_socket USE CONFIGURATION work.fulladder_config
            PORT MAP (x1, x2, x3, x4, x5);
        END FOR;
    END FOR;

END fulladder_tb_config;
