------------------------------------------------------------------------------
--
-- Filename:                bcd_4bit.vhd
-- Inhalt:                  Strukturale Beschreibung der Anzeigesteuerung
--                          (Steuerung einer 4-stelligen BCD-Anzeige)
--
------------------------------------------------------------------------------
--
-- Autor:                   Gunther Lehmann
-- Letzte Aenderung:        07.02.94
--
------------------------------------------------------------------------------

USE work.bcd.ALL;
ENTITY bcd_4bit IS
	PORT( bcd4: IN inptype;
			takt: IN bit;
			a,b,c,d,e,f,g: OUT bit;
			stelle1,stelle2,stelle3,stelle4: OUT bit);
END bcd_4bit;

------------------------------------------------------------------------------

ARCHITECTURE structural OF bcd_4bit IS
	COMPONENT mux_soc
		PORT( inp: IN inptype;
			outp: OUT bit_vector ( 0 TO 3);
			sel: IN bit_vector ( 0 TO 1));
	END COMPONENT;
	COMPONENT bcd_soc
		PORT( bcd: IN bit_vector (0 TO 3);
				a,b,c,d,e,f,g: OUT bit);
	END COMPONENT;
	COMPONENT dx_soc
		PORT(sel: IN bit_vector ( 0 TO 1);
			stelle1,stelle2,stelle3,stelle4:  OUT bit);
	END COMPONENT;
	COMPONENT ctr_soc
		PORT( takt: IN bit; cnt: OUT bit_vector ( 0 TO 1));
	END COMPONENT;

	SIGNAL sel: bit_vector ( 0 TO 1);
	SIGNAL bcd_nr: bit_vector ( 0 TO 3);
BEGIN
	mux: mux_soc
		PORT MAP (bcd4,bcd_nr,sel);
	bcd: bcd_soc
		PORT MAP (bcd_nr,a,b,c,d,e,f,g);
	dx: dx_soc
		PORT MAP (sel,stelle1,stelle2,stelle3,stelle4);
	ctr: ctr_soc
		PORT MAP (takt,sel);

END structural;

------------------------------------------------------------------------------

CONFIGURATION bcd_4bit_config OF bcd_4bit IS
	FOR structural
		FOR mux: mux_soc
			USE ENTITY work.mux (behavioral);
		END FOR;
		FOR bcd: bcd_soc
			USE ENTITY work.bcd_7seg (behavioral);
		END FOR;
		FOR dx: dx_soc
			USE ENTITY work.dx (behavioral);
		END FOR;
		FOR ctr: ctr_soc
			USE ENTITY work.ctr (behavioral);
		END FOR;
	END FOR;
END bcd_4bit_config;

