------------------------------------------------------------------------------
--
-- Filename:                tab.vhd
-- Inhalt:                  Verhaltensmodell des Automaten eines
--                          Telefon-Anrufbeantworters
--
------------------------------------------------------------------------------
--
-- Author:                  Bernhard Wunder  
-- Letzte Aenderung:        17.12.93
--
------------------------------------------------------------------------------

ENTITY tab_fsm IS

   PORT (clk, reset : IN bit ;
         anruf, hoerer_aufgelegt, ansage_fertig, timer_ende : IN bit ;
         timer_start, ansage_abspielen, anruf_aufzeichnen : OUT bit) ;

   TYPE fsm_state IS (ruhe, warten, ansage, aufzeichnen, telefonieren) ;

END tab_fsm ;

------------------------------------------------------------------------------

ARCHITECTURE behavioral OF tab_fsm IS

   SIGNAL state : fsm_state := ruhe ;

BEGIN

   new_state : PROCESS (clk, reset)

   BEGIN

      IF (reset = '1') THEN
         state <= ruhe ;
      ELSIF (clk = '1' AND clk'EVENT) THEN

         CASE state IS
            WHEN ruhe =>
               IF hoerer_aufgelegt = '0' THEN
                  state <= telefonieren ;
               ELSIF hoerer_aufgelegt = '1' AND anruf = '1' THEN
                  state <= warten ; 
               END IF ;

            WHEN warten =>
               IF hoerer_aufgelegt = '0' THEN
                  state <= telefonieren ;
               ELSIF hoerer_aufgelegt = '1' AND anruf = '0' THEN
                  state <= ruhe ;
               ELSIF hoerer_aufgelegt = '1' AND anruf = '1' AND timer_ende = '1' THEN
                  state <= ansage ;
               END IF ;

            WHEN ansage =>
               IF hoerer_aufgelegt = '0' THEN
                  state <= telefonieren ;
               ELSIF hoerer_aufgelegt = '1' AND anruf = '0' THEN
                  state <= ruhe ;
               ELSIF hoerer_aufgelegt = '1' AND anruf = '1' AND ansage_fertig = '1' THEN
                  state <= aufzeichnen ;
               END IF ;

            WHEN aufzeichnen =>
               IF hoerer_aufgelegt = '0' THEN
                  state <= telefonieren ;
               ELSIF hoerer_aufgelegt = '1' AND anruf = '0' THEN
                  state <= ruhe ;
               END IF ;

            WHEN telefonieren =>
               IF hoerer_aufgelegt = '1' AND anruf = '0' THEN
                  state <= ruhe ;
               END IF ;
         END CASE ;

      END IF ;


   END PROCESS ;


   output_assignment : PROCESS (state)

   BEGIN

      CASE state IS
         WHEN ruhe =>
            timer_start <= '0' ;
            ansage_abspielen <= '0' ;
            anruf_aufzeichnen <= '0' ;
         WHEN warten =>
            timer_start <= '1' ;
            ansage_abspielen <= '0' ;
            anruf_aufzeichnen <= '0' ;
         WHEN ansage =>
            timer_start <= '0' ;
            ansage_abspielen <= '1' ;
            anruf_aufzeichnen <= '0' ;
         WHEN aufzeichnen =>
            timer_start <= '0' ;
            ansage_abspielen <= '0' ;
            anruf_aufzeichnen <= '1' ;
         WHEN telefonieren =>
            timer_start <= '0' ;
            ansage_abspielen <= '0' ;
            anruf_aufzeichnen <= '0' ;
      END CASE ;

   END PROCESS ;

END behavioral ;
